==> style-o-matic-1.1.5.tgz: package/es/components/Modal/Modal.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import ReactDOM from "react-dom";
import cx from "classnames";
import { CoreComponent, setCorePropDefaults, setCorePropTypes, getValidProps, ROLE } from "../../lib";

import ModalHeader from "./ModalHeader";
import ModalContent from "./ModalContent";
import ModalFooter from "./ModalFooter";

import "./Modal.css";

var Modal = (_temp = _class = function (_CoreComponent) {
  _inherits(Modal, _CoreComponent);

  function Modal(props, context) {
    _classCallCheck(this, Modal);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props, context));

    _this.handleOpen = function () {
      _this.setState({ open: true });
    };

    _this.handleClose = function () {
      _this.setState({ open: false });
    };

    _this.handleToggle = function () {
      _this.setState({ open: !_this.state.open });
    };

    _this.handleClickShield = function (e) {
      e.preventDefault();
      e.stopPropagation();
    };

    _this.useParentNode = true;
    _this.elevatedContainer = null;
    _this.state = {
      open: false
    };
    return _this;
  }

  Modal.prototype.componentDidMount = function componentDidMount() {
    if (!this.elevatedContainer) {
      this.elevatedContainer = document.getElementById("modal-container");
      if (!this.elevatedContainer) {
        this.elevatedContainer = document.createElement("div");
        this.elevatedContainer.setAttribute("id", "modal-container");
        document.body.appendChild(this.elevatedContainer);
      }
    }
  };

  Modal.prototype.componentDidUpdate = function componentDidUpdate() {
    this.renderElevated(this.props);
  };

  Modal.prototype.renderElevated = function renderElevated(activeProps) {
    var _this2 = this;

    var _getValidProps = getValidProps(activeProps, this.state),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    if (this.elevatedContainer) {
      ReactDOM.render(React.createElement(
        Component,
        props,
        React.createElement(
          "div",
          {
            className: "ui-modal-outer-wrapper",
            role: "presentation",
            onClick: this.handleClose
          },
          React.createElement(
            "div",
            {
              className: "ui-modal-inner-wrapper",
              role: "presentation",
              onClick: this.handleClickShield
            },
            React.createElement(
              "div",
              {
                className: "ui-modal-dialog",
                role: "presentation",
                onClick: this.handleClickShield
              },
              React.createElement(
                "div",
                {
                  className: "ui-modal-close",
                  role: "presentation",
                  onClick: this.handleClose
                },
                React.createElement("i", { className: "ui-icon ui-icon-close", "aria-hidden": "true" })
              ),
              React.Children.map(children, function (child) {
                if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
                  return _this2.renderChild(child, inherited);
                }
                return child;
              })
            )
          )
        )
      ), this.elevatedContainer);
    }
  };

  Modal.prototype.render = function render() {
    this.parentNode.onclick = this.handleToggle;
    return React.createElement("span", { ref: this.onSetRef });
  };

  return Modal;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.MODAL
}), _class.Header = ModalHeader, _class.Content = ModalContent, _class.Footer = ModalFooter, _temp);


export default Modal;

==> style-o-matic-1.1.37.tgz: package/es/components/Modal/Modal.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import ReactDOM from "react-dom";
import cx from "classnames";
import { CoreComponent, getCorePropDefaults, getCorePropTypes, getValidProps, ROLE } from "../../lib";

import ModalHeader from "./ModalHeader";
import ModalContent from "./ModalContent";
import ModalFooter from "./ModalFooter";

import "./Modal.css";

var Modal = (_temp = _class = function (_CoreComponent) {
  _inherits(Modal, _CoreComponent);

  function Modal(props, context) {
    _classCallCheck(this, Modal);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props, context));

    _this.handleOpen = function () {
      _this.setState({ open: true });
    };

    _this.handleClose = function () {
      _this.setState({ open: false });
    };

    _this.handleToggle = function () {
      _this.setState({ open: !_this.state.open });
    };

    _this.handleClickShield = function (e) {
      e.preventDefault();
      e.stopPropagation();
    };

    _this.useParentNode = true;
    _this.elevatedContainer = null;
    _this.state = {
      open: false
    };
    return _this;
  }

  Modal.prototype.componentDidMount = function componentDidMount() {
    if (!this.elevatedContainer) {
      this.elevatedContainer = document.getElementById("modal-container");
      if (!this.elevatedContainer) {
        this.elevatedContainer = document.createElement("div");
        this.elevatedContainer.setAttribute("id", "modal-container");
        document.body.appendChild(this.elevatedContainer);
      }
    }
  };

  Modal.prototype.componentDidUpdate = function componentDidUpdate() {
    this.renderElevated(this.props);
  };

  Modal.prototype.renderElevated = function renderElevated(activeProps) {
    var _this2 = this;

    var _getValidProps = getValidProps(activeProps, this.state),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    if (this.elevatedContainer) {
      ReactDOM.render(React.createElement(
        Component,
        props,
        React.createElement(
          "div",
          {
            className: "ui-modal-outer-wrapper",
            role: "presentation",
            onClick: this.handleClose
          },
          React.createElement(
            "div",
            {
              className: "ui-modal-inner-wrapper",
              role: "presentation",
              onClick: this.handleClickShield
            },
            React.createElement(
              "div",
              {
                className: "ui-modal-dialog",
                role: "presentation",
                onClick: this.handleClickShield
              },
              React.createElement(
                "div",
                {
                  className: "ui-modal-close",
                  role: "presentation",
                  onClick: this.handleClose
                },
                React.createElement("i", { className: "ui-icon ui-icon-close", "aria-hidden": "true" })
              ),
              React.Children.map(children, function (child) {
                if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
                  return _this2.renderChild(child, inherited);
                }
                return child;
              })
            )
          )
        )
      ), this.elevatedContainer);
    }
  };

  Modal.prototype.render = function render() {
    this.parentNode.onclick = this.handleToggle;
    return React.createElement("span", { ref: this.onSetRef });
  };

  return Modal;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.MODAL
}), _class.Header = ModalHeader, _class.Content = ModalContent, _class.Footer = ModalFooter, _temp);


export default Modal;
